@@ -165,7 +165,9 @@ prop_test.formula <-
       data <- environment(x)
     }
     
-    formula <- mosaic_formula_q(x, groups=groups, max.slots=2)
+    formula <- 
+      mosaicCore::mosaic_formula_q(x, groups = !!rlang::enexpr(groups), max.slots = 2)
+    
     missing_data.name <- missing(data.name)
     if (is.null(data)) {
       data <- environment(x)
